/*
* jquery.categorygallery.js 1.0 | 4/18/16
* 
* Enables gallery + nav to indicate images based on selected category by making non-selected category images (& non-active links) transparent
*
* Copyright 2016, Kelly Meyers http://merexcursion.com
* Released under the GPL v3 License http://www.gnu.org/licenses/gpl.html
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* Instructions:
* 1. Wrap gallery images and category nav in containing element with id="your-gallery-name"
* 2. Give each gallery link class "category", and each gallery image or img container class "gallery-item"
* 3. To each .gallery-item, add a class name for the category(s) it belongs to (ex: web, illustration, animation...)
* 4. Add to each gallery link data-filter=".category-name" to select the category(s) added to gallery items when clicked
* 5. Add script link to this file in the document head after jQuery lib 
*    and activate plugin on element in jQuery doc ready fn: 
*    $('#your-gallery-name').categorygallery();
* You may override class names .category & .gallery-item with options:
* $('#your-gallery-name').categorygallery( { 'navLink':'.your-link-class', 'galleryItem':'.your-gallery-item-class' } );
* You can use the '*' for the data-filter to show all
*  
*/
(function( $ ){
	  'use strict';
	
	  $.fn.categorygallery = function( options ) {
		  
			var thisOpts = $.extend( {}, $.fn.categorygallery.defaults, options );
		
			return this.each(function(){
		
				var elem = $(this);
				var opts = thisOpts;
				var highlight;
				var $navLinks = $(elem).find(opts.navLink);
				var $galleryItems = $(elem).find(opts.galleryItem);
				var linkOpacitySettings = {
					'opacity':0.7,
					'filter':'alpha(opacity=70)'
				};
				var itemOpacitySettings = {
					'opacity':0.3,
					'filter':'alpha(opacity=30)'
				};
				var highlightOpacitySettings = {
					'opacity':1,
					'filter':'alpha(opacity=100)'
				};
		
				// link action
				$navLinks.on('click', function(event){
					event.preventDefault();
					
					// link opacity
					$navLinks.css(linkOpacitySettings);
					$(event.target).css(highlightOpacitySettings);
					
					// item opacity
					highlight = $(this).attr('data-filter');
					highlightImages(highlight);
					
					// ensure highlight
					$(this).blur();
				});
				
				function highlightImages(highlightIn){
					if(highlightIn === '*'){
						$.each( $galleryItems, function(){
							$(this).animate(highlightOpacitySettings); // fade in
						});
						
					} else {
						$.each( $galleryItems, function(){
							$(this).not(highlightIn).animate(itemOpacitySettings); // fade out
						});
						
						$(elem).find(highlightIn).animate(highlightOpacitySettings); // fade in
					}
				}
			});
		
		  };
		// Defaults
		$.fn.categorygallery.defaults = {
			navLink: '.category',
			galleryItem: '.gallery-item'
		};

})( jQuery );
